@@ -101,7 +101,7 @@ def hashivault_auth(client, params):
     if authtype == 'github':
         client.auth.github.login(token, mount_point=login_mount_point)
     elif authtype == 'userpass':
-        client.auth_userpass(username, password, mount_point=login_mount_point)
+        client.auth.userpass.login(username, password, mount_point=login_mount_point)
     elif authtype == 'ldap':
         client.auth.ldap.login(username, password, mount_point=login_mount_point)
     elif authtype == 'approle':
@@ -183,11 +183,13 @@ def hashivault_read(params):
     if version == 2:
         try:
             data = response.get('data', {})
+            metadata = data.get('metadata', {})
             data = data.get('data', {})
         except Exception:
             data = str(response)
     else:
         data = response['data']
+        metadata = {}
     lease_duration = response.get('lease_duration', None)
     if lease_duration is not None:
         result['lease_duration'] = lease_duration
@@ -213,6 +215,7 @@ def hashivault_read(params):
     else:
         value = data
     result['value'] = value
+    result['metadata'] = metadata
     return result
 
 
